@@ -20,18 +20,17 @@ sub new {
     $self->{'connect'}->SetToolTip('connect the points / dots');
 
     my $row1 = Wx::BoxSizer->new(&Wx::wxHORIZONTAL);
-    $row1->Add( $self->{'length'},  0, &Wx::wxALIGN_LEFT| &Wx::wxGROW | &Wx::wxLEFT, 10);
-#    $row1->AddSpacer(20);
-    $row1->Add( $self->{'density'}, 0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW| &Wx::wxLEFT, 10);
+    $row1->AddSpacer(  15 );
+    $row1->Add( $self->{'connect'},    0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW|&Wx::wxALL, 5);
+    $row1->AddSpacer( 210 );
+    $row1->Add( $self->{'length'},  0, &Wx::wxALIGN_LEFT| &Wx::wxGROW | &Wx::wxALL, 5);
     $row1->Add( 0, 0, &Wx::wxEXPAND);
     
     my $row2 = Wx::BoxSizer->new(&Wx::wxHORIZONTAL);
-    $row2->AddSpacer(  15 );
-    $row2->Add( $self->{'connect'},    0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW|&Wx::wxALL, 5);
-    $row2->AddSpacer( 191 );
-   # $row2->Add( Wx::StaticText->new($self, -1, 'Thickness'), 0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW|&Wx::wxALL, 10);
+    $row2->Add( $self->{'density'}, 0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW| &Wx::wxLEFT, 10);
+    # $row2->Add( Wx::StaticText->new($self, -1, 'Thickness'), 0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW|&Wx::wxALL, 10);
     $row2->Add( $self->{'thickness'},  0, &Wx::wxALIGN_LEFT| &Wx::wxGROW | &Wx::wxALL, 5);
-   # $row2->Add( Wx::StaticText->new($self, -1, 'Px'), 0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW|&Wx::wxALL, 10);
+    # $row2->Add( Wx::StaticText->new($self, -1, 'Px'), 0, &Wx::wxALIGN_CENTER_VERTICAL|&Wx::wxGROW|&Wx::wxALL, 10);
     $row2->Add( 0, 0, &Wx::wxEXPAND);
     
     my $sizer = Wx::BoxSizer->new(&Wx::wxVERTICAL);
@@ -53,10 +52,10 @@ sub init {
 sub get_data {
     my ( $self ) = @_;
     {
-        length    => $self->{'length'}->GetValue,
-        density   => $self->{'density'}->GetValue,
-        thickness => $self->{'thickness'}->GetValue,
-        connect      => $self->{'connect'}->GetValue,
+        'length'    => $self->{ 'length' }->GetValue,
+        'density'   => $self->{ 'density' }->GetValue,
+        'thickness' => $self->{ 'thickness' }->GetValue,
+        'connect'   => $self->{ 'connect' }->GetValue,
     }
 }
 
